@@ -1,7 +1,8 @@
-__version__ = "1.1.3"
+__version__ = "1.2.0"
 __author__ = "Jiace Sun"
 
 import os
 ROOT = os.path.dirname(os.path.abspath(__file__))
 from . import config
-from .translate_tex import translate_tex
+from . import translation
+from .translation import translate
